@@ -8,7 +8,7 @@ use Moose::Util::TypeConstraints qw(enum subtype where);
 use List::Util qw(uniq any first);
 use namespace::autoclean;
 
-our $VERSION = '1.3';
+our $VERSION = '1.4';
 
 with
     'Dist::Zilla::Role::PluginBundle::Easy',
@@ -105,12 +105,10 @@ sub _warn_me {
     warn(sprintf("[\@Author::WATERKIP]  %s\n", $msg));
 }
 
-
 sub commit_files_after_release {
     grep { -e } sort(uniq('README.md', 'README.pod', 'Changes', shift->copy_files_from_release));
 }
 
-
 my %removed;
 
 sub configure {
@@ -229,7 +227,7 @@ Dist::Zilla::PluginBundle::Author::WATERKIP - An plugin bundle for all distribut
 
 =head1 VERSION
 
-version 1.3
+version 1.4
 
 =head1 SYNOPSIS
 
@@ -237,6 +235,16 @@ In your F<dist.ini>:
 
     [@Author::WATERKIP]
 
+=head1 METHODS
+
+=head2 configure
+
+Configure the author plugin
+
+=head2 commit_files_after_release
+
+Commit files after a release
+
 =head1 SEE ALSO
 
 I took inspiration from L<Dist::Zilla::PluginBundle::Author::ETHER>
